<?php

/* --------------------------------------------------------------
   ContentOpengraphImage.inc.php 2019-04-11
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class ContentOpengraphImage
 *
 * This class represents the localized content OpenGraph image
 *
 * @category   System
 * @package    Content
 */
class ContentOpengraphImage implements LocalizedContentAttributeInterface
{
    /**
     * Content OpenGraph image
     *
     * @var StringType
     */
    protected $opengraphImage;
    
    /**
     * Language code
     *
     * @var string
     */
    protected $languageCode;
    
    
    /**
     * ContentOpengraphImage constructor
     *
     * @param \StringType $opengraphImage Content OpenGraph image
     * @param LanguageCode $languageCode Language code
     */
    public function __construct(StringType $opengraphImage, LanguageCode $languageCode)
    {
        if (!strlen($opengraphImage->asString())) {
            throw new InvalidArgumentException('Empty OpenGraph image provided');
        }
        
        $this->opengraphImage = $opengraphImage;
        $this->languageCode = $languageCode->asString();
    }
    
    
    /**
     * Return the content OpenGraph image
     *
     * @return string
     */
    public function content()
    {
        return $this->opengraphImage->asString();
    }
    
    
    /**
     * Return the language code
     *
     * @return string
     */
    public function languageCode()
    {
        return $this->languageCode;
    }
}